@@ -749,7 +749,9 @@ async def cp(
                     raise RuntimeError(
                         f"Copy operation of the file with scheme '{source.scheme}'"
                         f" to the file with scheme '{destination.scheme}'"
-                        f" is not supported"
+                        f" is not supported."
+                        " Checkout 'neuro-extras data --help',"
+                        " maybe it will suite your use-case?"
                     )
         except (OSError, ResourceNotFound, IllegalArgumentError) as error:
             log.error(f"cannot copy {source} to {destination}: {error}")
