@@ -10,7 +10,7 @@ import pytest
 from jose import jwt
 from yarl import URL
 
-from neuro_sdk import Client, Cluster, Preset, __version__
+from neuro_sdk import Client, Cluster, PluginManager, Preset, __version__
 from neuro_sdk.config import _AuthConfig, _AuthToken, _ConfigData, _save
 from neuro_sdk.tracing import _make_trace_config
 
@@ -66,11 +66,11 @@ def cluster_config() -> Cluster:
     return Cluster(
         registry_url=URL("https://registry-dev.neu.ro"),
         storage_url=URL("https://storage-dev.neu.ro"),
-        blob_storage_url=URL("https://blob-storage-dev.neu.ro"),
         users_url=URL("https://users-dev.neu.ro"),
         monitoring_url=URL("https://monitoring-dev.neu.ro"),
         secrets_url=URL("https://secrets-dev.neu.ro"),
         disks_url=URL("https://disks-storage-dev.neu.ro"),
+        buckets_url=URL("https://buckets-storage-dev.neu.ro"),
         presets={
             "gpu-small": Preset(
                 credits_per_hour=Decimal("10"),
@@ -114,7 +114,8 @@ def make_client(
         registry_url: str = "https://registry-dev.neu.ro",
         trace_id: str = "bd7a977555f6b982",
         clusters: Optional[Dict[str, Cluster]] = None,
-        token_url: Optional[URL] = None
+        token_url: Optional[URL] = None,
+        plugin_manager: Optional[PluginManager] = None,
     ) -> Client:
         url = URL(url_str)
         if clusters is None:
@@ -122,10 +123,10 @@ def make_client(
                 registry_url=URL(registry_url),
                 monitoring_url=(url / "jobs"),
                 storage_url=(url / "storage"),
-                blob_storage_url=(url / "blob"),
                 users_url=url,
                 secrets_url=(url / "secrets"),
                 disks_url=(url / "disks"),
+                buckets_url=(url / "buckets"),
                 presets={
                     "gpu-small": Preset(
                         credits_per_hour=Decimal("10"),
@@ -155,6 +156,8 @@ def make_client(
             real_auth_config = replace(auth_config, token_url=token_url)
         else:
             real_auth_config = auth_config
+        if plugin_manager is None:
+            plugin_manager = PluginManager()
         config = _ConfigData(
             auth_config=real_auth_config,
             auth_token=_AuthToken.create_non_expiring(token),
@@ -167,6 +170,12 @@ def make_client(
         config_dir = tmp_path / ".neuro"
         _save(config, config_dir)
         session = aiohttp.ClientSession(trace_configs=[_make_trace_config()])
-        return Client._create(session, config_dir, trace_id)
+        return Client._create(
+            session,
+            config_dir,
+            trace_id,
+            None,
+            plugin_manager=plugin_manager,
+        )
 
     return go
