@@ -3,6 +3,7 @@ import itertools
 import sys
 from dataclasses import replace
 from datetime import datetime, timedelta, timezone
+from decimal import Decimal
 from typing import Any, Callable, Optional
 
 import pytest
@@ -111,6 +112,8 @@ def job_descr_no_name() -> JobDescription:
         ),
         scheduler_enabled=True,
         pass_config=True,
+        total_price_credits=Decimal("150"),
+        price_credits_per_hour=Decimal("15"),
     )
 
 
@@ -137,6 +140,8 @@ def job_descr() -> JobDescription:
         ),
         scheduler_enabled=True,
         pass_config=True,
+        total_price_credits=Decimal("150"),
+        price_credits_per_hour=Decimal("15"),
     )
 
 
@@ -149,6 +154,8 @@ class TestJobStartProgress:
         name: Optional[str] = None,
         life_span: Optional[float] = None,
         description: str = "ErrorDesc",
+        total_price_credits: Decimal = Decimal("150"),
+        price_credits_per_hour: Decimal = Decimal("15"),
     ) -> JobDescription:
         return JobDescription(
             name=name,
@@ -183,6 +190,8 @@ class TestJobStartProgress:
             scheduler_enabled=False,
             pass_config=True,
             life_span=life_span,
+            total_price_credits=total_price_credits,
+            price_credits_per_hour=price_credits_per_hour,
         )
 
     def test_quiet(self, rich_cmp: Any, new_console: _NewConsole) -> None:
@@ -296,6 +305,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -334,6 +345,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -372,6 +385,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -410,6 +425,8 @@ class TestJobOutputFormatter:
             scheduler_enabled=False,
             pass_config=True,
             life_span=1.0 * ((60 * 60 * 24 * 1) + (60 * 60 * 2) + (60 * 3) + 4),
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -448,6 +465,8 @@ class TestJobOutputFormatter:
             scheduler_enabled=False,
             pass_config=True,
             life_span=0.0,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -487,6 +506,8 @@ class TestJobOutputFormatter:
             scheduler_enabled=False,
             pass_config=True,
             restart_policy=JobRestartPolicy.ALWAYS,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -524,6 +545,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -558,6 +581,8 @@ class TestJobOutputFormatter:
             owner="owner",
             cluster_name="default",
             uri=URL("job://default/owner/test-job"),
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -593,6 +618,8 @@ class TestJobOutputFormatter:
             owner="owner",
             cluster_name="default",
             uri=URL("job://default/owner/test-job"),
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -627,6 +654,8 @@ class TestJobOutputFormatter:
             owner="owner",
             cluster_name="default",
             uri=URL("job://default/owner/test-job"),
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -663,6 +692,8 @@ class TestJobOutputFormatter:
             scheduler_enabled=False,
             pass_config=True,
             internal_hostname="host.local",
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -720,6 +751,8 @@ class TestJobOutputFormatter:
             scheduler_enabled=False,
             pass_config=True,
             internal_hostname="host.local",
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -758,6 +791,8 @@ class TestJobOutputFormatter:
             pass_config=True,
             internal_hostname="host.local",
             internal_hostname_named="test-job--test-owner.local",
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -795,6 +830,8 @@ class TestJobOutputFormatter:
             scheduler_enabled=False,
             pass_config=True,
             internal_hostname="host.local",
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -840,6 +877,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -901,6 +940,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -957,6 +998,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         rich_cmp(
@@ -1027,6 +1070,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -1088,6 +1133,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -1133,6 +1180,8 @@ class TestJobOutputFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -1168,6 +1217,8 @@ class TestJobOutputFormatter:
             owner="owner",
             cluster_name="default",
             uri=URL("job://default/owner/test-job"),
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -1203,6 +1254,84 @@ class TestJobOutputFormatter:
             owner="owner",
             cluster_name="default",
             uri=URL("job://default/owner/test-job"),
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
+        )
+
+        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
+            )(description)
+        )
+
+    def test_job_with_org_name(
+        self, rich_cmp: Any, datetime_formatter: DatetimeFormatter
+    ) -> None:
+        description = JobDescription(
+            status=JobStatus.RUNNING,
+            owner="test-user",
+            name="test-job",
+            cluster_name="default",
+            org_name="test-job-org-name",
+            id="test-job",
+            uri=URL("job://default/test-user/test-job"),
+            history=JobStatusHistory(
+                status=JobStatus.RUNNING,
+                reason="ContainerRunning",
+                description="",
+                created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
+                started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
+                finished_at=None,
+            ),
+            http_url=URL("http://local.host.test/"),
+            container=Container(
+                command="test-command",
+                image=RemoteImage.new_external_image(name="test-image"),
+                resources=Resources(16, 0.1, 0, None, False, None, None),
+            ),
+            scheduler_enabled=False,
+            pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
+        )
+
+        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=datetime_formatter
+            )(description)
+        )
+
+    def test_job_with_partial_credits(
+        self, rich_cmp: Any, datetime_formatter: DatetimeFormatter
+    ) -> None:
+        description = JobDescription(
+            status=JobStatus.RUNNING,
+            owner="test-user",
+            name="test-job",
+            cluster_name="default",
+            org_name="test-job-org-name",
+            id="test-job",
+            uri=URL("job://default/test-user/test-job"),
+            history=JobStatusHistory(
+                status=JobStatus.RUNNING,
+                reason="ContainerRunning",
+                description="",
+                created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
+                started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
+                finished_at=None,
+            ),
+            http_url=URL("http://local.host.test/"),
+            container=Container(
+                command="test-command",
+                image=RemoteImage.new_external_image(name="test-image"),
+                resources=Resources(16, 0.1, 0, None, False, None, None),
+            ),
+            scheduler_enabled=False,
+            pass_config=True,
+            total_price_credits=Decimal(150 / 15000),
+            price_credits_per_hour=Decimal(15 / 15000),
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
@@ -1450,6 +1579,8 @@ class TestSimpleJobsFormatter:
                 ),
                 scheduler_enabled=True,
                 pass_config=True,
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             ),
             JobDescription(
                 status=JobStatus.PENDING,
@@ -1472,6 +1603,8 @@ class TestSimpleJobsFormatter:
                 ),
                 scheduler_enabled=True,
                 pass_config=True,
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             ),
         ]
         formatter = SimpleJobsFormatter()
@@ -1510,6 +1643,8 @@ class TestTabularJobRow:
             ),
             scheduler_enabled=True,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
     def test_with_job_name(self, datetime_formatter: DatetimeFormatter) -> None:
@@ -1646,6 +1781,8 @@ class TestTabularJobsFormatter:
             ),
             scheduler_enabled=True,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
         formatter = TabularJobsFormatter(
             "owner",
@@ -1695,6 +1832,8 @@ class TestTabularJobsFormatter:
                 ),
                 scheduler_enabled=True,
                 pass_config=True,
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             ),
             JobDescription(
                 status=JobStatus.PENDING,
@@ -1728,6 +1867,8 @@ class TestTabularJobsFormatter:
                 ),
                 scheduler_enabled=True,
                 pass_config=True,
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             ),
         ]
         formatter = TabularJobsFormatter(
@@ -1764,6 +1905,8 @@ class TestTabularJobsFormatter:
             ),
             scheduler_enabled=True,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         columns = parse_ps_columns("{status;align=right;min=20;Status Code}")
@@ -1804,6 +1947,8 @@ class TestTabularJobsFormatter:
                 scheduler_enabled=True,
                 pass_config=True,
                 life_span=life_span,
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             )
             for i, life_span in enumerate(life_spans, 1)
         ]
@@ -1869,6 +2014,8 @@ class TestTabularJobsFormatter:
                 scheduler_enabled=False,
                 pass_config=True,
                 internal_hostname="host.local",
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             )
             for i, item in enumerate(items, 1)
         ]
@@ -1911,6 +2058,8 @@ class TestTabularJobsFormatter:
                 scheduler_enabled=False,
                 pass_config=True,
                 internal_hostname="host.local",
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             )
             for i, working_dir in enumerate(items, 1)
         ]
@@ -1951,6 +2100,8 @@ class TestTabularJobsFormatter:
                 pass_config=True,
                 internal_hostname="host.local",
                 preset_name=preset_name,
+                total_price_credits=Decimal("150"),
+                price_credits_per_hour=Decimal("15"),
             )
             for i, preset_name in enumerate(items, 1)
         ]
@@ -2012,6 +2163,8 @@ class TestLifeSpanUpdateFormatter:
             ),
             scheduler_enabled=False,
             pass_config=True,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         formatter = LifeSpanUpdateFormatter(
@@ -2045,6 +2198,8 @@ class TestLifeSpanUpdateFormatter:
             scheduler_enabled=False,
             pass_config=True,
             life_span=3600,
+            total_price_credits=Decimal("150"),
+            price_credits_per_hour=Decimal("15"),
         )
 
         formatter = LifeSpanUpdateFormatter(
